@@ -14,21 +14,21 @@ import execa = require('execa')
 
 export namespace OpenShift {
   export async function isOpenShiftRunning(): Promise<boolean> {
-    const {exitCode} = await execa('oc', ['status', '--namespace', 'default'], {timeout: 60000, reject: false})
+    const {exitCode} = await execa('oc', ['status', '--namespace', 'default'], {timeout: 60_000, reject: false})
     return exitCode === 0
   }
 
   export async function getRouteHost(name: string, namespace: string): Promise<string> {
     const command = 'oc'
     const args = ['get', 'route', '--namespace', namespace, '-o', `jsonpath={range.items[?(.metadata.name=='${name}')]}{.spec.host}{end}`]
-    const {stdout} = await execa(command, args, {timeout: 60000})
+    const {stdout} = await execa(command, args, {timeout: 60_000})
     return stdout.trim()
   }
 
   export async function isRouteExist(name: string, namespace: string): Promise<boolean> {
     const command = 'oc'
     const args = ['get', 'route', '--namespace', namespace, '-o', `jsonpath={range.items[?(.metadata.name=='${name}')]}{.metadata.name}{end}`]
-    const {stdout} = await execa(command, args, {timeout: 60000})
+    const {stdout} = await execa(command, args, {timeout: 60_000})
     return stdout.trim().includes(name)
   }
 }
